## 多语言SDK支持

易宝开放平台 SDK 是官方提供的开发工具包，封装了请求处理、签名加密、响应解析等核心功能，显著降低开发成本，提高开发效率。

支持的语言版本如下：
- Java SDK (yop-java-sdk)：支持 JDK 1.8 及以上版本，[GitHub](https://github.com/yop-platform/yop-java-sdk)，[使用说明](https://open.yeepay.com/apis/docs/platform/20250420205103/sdk_guide/java-sdk-guide.html)
- PHP SDK (yop-php-sdk)：需要 PHP 5.5 及以上版本，[GitHub](https://github.com/yop-platform/yop-php-sdk)，[使用说明](https://open.yeepay.com/apis/docs/platform/20250420205103/sdk_guide/php-sdk-guide.html)
- .NET SDK (yop-dotnet-sdk)：需要 .NET Framework 2.0 及以上版本，[源码地址](https://github.com/yop-platform/yop-dotnet-sdk)，不支持Windows Phone平台，[使用说明](https://open.yeepay.com/apis/docs/platform/20250420205103/sdk_guide/dotnet-sdk-guide.html)
- TypeScript SDK (yop-typescript-sdk)：需要 Node.js 18.0.0 及以上版本，[GitHub](https://github.com/yop-platform/yop-typescript-sdk)，[NPM](https://www.npmjs.com/package/yop-typescript-sdk)，安装方法：`npm i yop-typescript-sdk`
- Node.js SDK (yop-nodejs-sdk)：需要 Node.js 18.0.0 及以上版本，[GitHub](https://github.com/yop-platform/yop-nodejs-sdk)，[NPM](https://www.npmjs.com/package/yop-nodejs-sdk)，安装方法：`npm i yop-nodejs-sdk`
- Python SDK (yop-python-sdk)：需要 Python 2.7 及以上版本，[GitHub](https://github.com/yop-platform/yop-python-sdk)，[使用说明](https://open.yeepay.com/apis/docs/platform/20250420205103/sdk_guide/python-sdk-guide.html)
- Go SDK (yop-go-sdk)：建议使用 Go 1.18 及以上版本，[GitHub](https://github.com/yop-platform/yop-go-sdk)